from pydantic import BaseModel, Field
from typing import Optional, List
from datetime import datetime,date
from gai.rag.dtos.indexed_doc_chunkgroup import IndexedDocChunkGroupPydantic

class IndexedDocHeaderPydantic(BaseModel):
    Id: str = Field(...)
    CollectionName: str
    ByteSize: int
    FileName: Optional[str] = None
    FileType: Optional[str] = None
    Source: Optional[str] = None
    Abstract: Optional[str] = None
    Authors: Optional[str] = None
    Title: Optional[str] = None
    Publisher: Optional[str] = None
    PublishedDate: Optional[date] = None
    Comments: Optional[str] = None
    Keywords: Optional[str] = None
    CreatedAt: datetime
    UpdatedAt: datetime
    IsActive: bool = True
    ChunkGroups: Optional[List[IndexedDocChunkGroupPydantic]] = None




from pydantic import BaseModel, ConfigDict, Field
from typing import Optional
from uuid import UUID

class IndexedDocChunkPydantic(BaseModel):
    Id: str = Field(...)  # The ellipsis here indicates a required field with no default value
    ChunkHash: str
    ChunkGroupId: str
    ByteSize: int
    IsDuplicate: bool
    IsIndexed: bool
    Content: Optional[str] = None

    model_config = ConfigDict(from_attributes=True)




from pydantic import BaseModel, ConfigDict, Field

# The ChunkInfo class is a subset of the Chunk model.
# 
class ChunkInfoPydantic(BaseModel):
    Id: str = Field(...)  # The ellipsis here indicates a required field with no default value
    ChunkHash: str = Field(...)  # The ellipsis here indicates a required field with no default value
    IsDuplicate: bool
    IsIndexed: bool
    model_config = ConfigDict(from_attributes=True)



from pydantic import BaseModel, Field
from typing import Optional
from uuid import uuid4

class IndexedDocChunkGroupPydantic(BaseModel):
    Id: str = Field(default_factory=uuid4)
    DocumentId: str  # Assuming DocumentId is also a UUID; adjust if it's not
    SplitAlgo: Optional[str] = None
    ChunkCount: int
    ChunkSize: int
    Overlap: int
    IsActive: bool = True
    ChunksDir: Optional[str] = None



from gai.rag.dtos.create_doc_header_request import CreateDocHeaderRequestPydantic
from typing import Optional

class CreateAgentDocHeaderRequestPydantic(CreateDocHeaderRequestPydantic):
    # Custom getter and setter for AgentId
    @property
    def AgentId(self) -> Optional[str]:
        # Get the value of CollectionName (treated as AgentId)
        return self.CollectionName

    @AgentId.setter
    def AgentId(self, value: Optional[str]) -> None:
        # Set the value of CollectionName (treated as AgentId)
        self.CollectionName = value


from pydantic import BaseModel
from typing import Optional
class CreateDocHeaderRequestPydantic(BaseModel):
    Id: Optional[str] = None
    CollectionName: Optional[str]
    FilePath: Optional[str]
    FileType: Optional[str] = None
    Source: Optional[str] = None
    ByteSize: Optional[int] = None
    Title: Optional[str] = None
    Abstract: Optional[str] = None
    Authors: Optional[str] = None
    Publisher: Optional[str] = None
    PublishedDate: Optional[str] = None
    Comments: Optional[str] = None
    Keywords: Optional[str] = None
    ChunkGroupId: Optional[str] = None
    ChunkSize: Optional[int] = None
    ChunkOverlap: Optional[int] = None
    ChunkCount: Optional[int] = None    